@@ -18,15 +18,24 @@ class ModelBaseMeta(base.ModelBase):
     '''
 
     def __new__(cls, name, bases, attrs):
-        class_ = base.ModelBase.__new__(cls, name, bases, attrs)
-        module_name = formatters.camel_to_underscore(name)
+        module = attrs['__module__']
 
-        app_label = class_.__module__.split('.')[-2]
-        db_table = '%s_%s' % (app_label, module_name)
-        if not getattr(class_._meta, 'proxy', False):
-            class_._meta.db_table = db_table
+        # Get or create Meta
+        if 'Meta' in attrs:
+            Meta = attrs['Meta']
+        else:
+            Meta = type('Meta', (object,), dict(
+                __module__=module,
+            ))
+            attrs['Meta'] = Meta
 
-        return class_
+        # Override table name only if not explicitly defined
+        if not hasattr(Meta, 'db_table'):  # pragma: no cover
+            module_name = formatters.camel_to_underscore(name)
+            app_label = module.split('.')[-2]
+            Meta.db_table = '%s_%s' % (app_label, module_name)
+
+        return base.ModelBase.__new__(cls, name, bases, attrs)
 
 
 class ModelBase(six.with_metaclass(ModelBaseMeta, models.Model)):
@@ -103,3 +112,29 @@ class SlugMixin(NameMixin):
 
     class Meta(object):
         unique_together = ('slug',)
+
+
+class NameModelBase(NameMixin, ModelBase):
+    name = models.CharField(max_length=100)
+
+    class Meta:
+        abstract = True
+
+
+class SlugModelBase(SlugMixin, NameModelBase):
+    slug = models.SlugField(max_length=50)
+
+    class Meta:
+        abstract = True
+
+
+class NameCreatedAtModelBase(NameModelBase, CreatedAtModelBase):
+
+    class Meta:
+        abstract = True
+
+
+class SlugCreatedAtModelBase(SlugModelBase, CreatedAtModelBase):
+
+    class Meta:
+        abstract = True
