@@ -2,18 +2,13 @@ from . import view_decorators
 from django import http
 
 
-@view_decorators.env(response_class=http.HttpResponseBadRequest)
-def error_400(request):
-    pass
-
-
 @view_decorators.env(response_class=http.HttpResponseForbidden)
-def error_403(request):
+def error_403(request, exception):
     pass
 
 
 @view_decorators.env(response_class=http.HttpResponseNotFound)
-def error_404(request):
+def error_404(request, exception):
     pass
 
 
